class URL:
    BASE = "https://api.culqi.com"
    VERSION = "v2"

    CARD = "cards"
    CHARGE = "charges"
    CUSTOMER = "customers"
    EVENT = "events"
    ORDER = "orders"
    PLAN = "plans"
    REFUND = "refunds"
    SUBSCRIPTION = "subscriptions"
    TOKEN = "tokens"

    TRANSFER = "transfers"
    IIN = "iins"
